@@ -4,6 +4,7 @@
 
 import subprocess
 import sys
+from enum import Enum
 from typing import List, Optional
 import unittest
 from pathlib import Path
@@ -23,10 +24,11 @@ start_dir: Optional[str] = None
 """Directory to start discovery. None means the first found directory with 
 '__init__.py' inside, starting recursive search from the current directory."""
 
-top_level_dir: Optional[str] = None
-"""Top level directory of project (defaults to start directory)"""
+top_level_dir: Optional[str] = '.'
+"""Top level directory of project (defaults to current directory).
+None will set to the same value as `start_dir`."""
 
-buffer = True
+buffer = False
 """Buffer stdout and stderr during tests"""
 
 failfast = False
@@ -35,7 +37,18 @@ failfast = False
 verbosity = 1
 """0 for quiet, 2 for verbose"""
 
-warnings = None
+
+class Warnings(Enum):
+    # https://www.geeksforgeeks.org/warnings-in-python/
+    default = "default"
+    error = "error"
+    ignore = "ignore"
+    always = "always"
+    module = "module"
+    once = "once"
+
+
+warnings: Warnings = Warnings.default
 
 
 ################################################################################
@@ -59,6 +72,20 @@ def suite() -> unittest.TestSuite:
         pattern=pattern)
 
 
+def __run_as_program():
+    # alternatively we can run the tests exactly as '-m unittest' does
+
+    argv = [sys.executable + ' -m unittest', 'discover', '-p', pattern, '-s', start_dir or str(init_py().parent), '-t',
+            top_level_dir]
+
+    return unittest.TestProgram(module=None,
+                                exit=False,
+                                verbosity=verbosity,
+                                failfast=failfast,
+                                buffer=buffer,
+                                argv=argv).result
+
+
 def run() -> unittest.TestResult:
     """Discovers and runs unit tests for the module."""
 
@@ -66,9 +93,10 @@ def run() -> unittest.TestResult:
         if subprocess.call([sys.executable, "-m", "pip", "install"] + deps) != 0:
             exit(1)
 
-    result = unittest.TextTestRunner(buffer=buffer, verbosity=verbosity, failfast=failfast, warnings=warnings).run(suite())
+    result = unittest.TextTestRunner(buffer=buffer, verbosity=verbosity, failfast=failfast,
+                                     warnings=warnings.value).run(suite())
 
-    if result.failures or result.errors:
+    if not result.wasSuccessful():
         exit(1)
 
     return result
